@@ -1,27 +1,27 @@
 #include <iostream>
 #include <cstring>
-#include <S.h>
+#include "verS.h"
 using namespace std;
 
 extern "C" {
 
-void fullId(char **id, long *idLength, long *familySizes,
-	    long *familySizesLength, long *loci, char **fullId,
-	    long *fullIdLength, long *idMaxLength) {
+void fullId(char **id, Sint *idLength, Sint *familySizes,
+	    Sint *familySizesLength, Sint *loci, char **fullId,
+	    Sint *fullIdLength, Sint *idMaxLength) {
 
-  long fullIdIndex = 0;
-  long baseFamilyIndex = 0;
-  long familySize = 0;
+  Sint fullIdIndex = 0;
+  Sint baseFamilyIndex = 0;
+  Sint familySize = 0;
 
   if(*idLength * *loci != *fullIdLength) {
     PROBLEM "*idLength * *loci = %ld, *fullIdLength = %ld\nThe values need to be equal.\nfullId.cpp key 18\n",
       (*idLength * *loci), *fullIdLength RECOVER(NULL_ENTRY);
   }
 
-  for(long i = 0; i < *familySizesLength; i++) {
+  for(Sint i = 0; i < *familySizesLength; i++) {
     familySize = familySizes[i];
-    for(long j = 0; j < *loci; j++) {
-      for(long k = 0; k < familySize; k++) {
+    for(Sint j = 0; j < *loci; j++) {
+      for(Sint k = 0; k < familySize; k++) {
 	//	fullId[fullIdIndex] = id[baseFamilyIndex + k];
 	//	cout << "i = " << i << ", j = " << j << ", k = " << k << endl;
 	strncpy(fullId[fullIdIndex], id[baseFamilyIndex + k], *idMaxLength);
